@@ -2,5 +2,5 @@
 
 from .runner import TAPTestRunner
 
-__all__ = ['TAPTestRunner']
-__version__ = '2.4'
+__all__ = ["TAPTestRunner"]
+__version__ = "2.5"
