@@ -5,11 +5,11 @@ import unittest
 
 from tap import TAPTestRunner
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     tests_dir = os.path.dirname(os.path.abspath(__file__))
     loader = unittest.TestLoader()
     tests = loader.discover(tests_dir)
     runner = TAPTestRunner()
-    runner.set_outdir('testout')
-    runner.set_format('Hi: {method_name} - {short_description}')
+    runner.set_outdir("testout")
+    runner.set_format("Hi: {method_name} - {short_description}")
     runner.run(tests)
