@@ -36,9 +36,9 @@ class TestParser(unittest.TestCase):
         """The parser extracts an ok line."""
         parser = Parser()
 
-        line = parser.parse_line('ok - This is a passing test line.')
+        line = parser.parse_line("ok - This is a passing test line.")
 
-        self.assertEqual('test', line.category)
+        self.assertEqual("test", line.category)
         self.assertTrue(line.ok)
         self.assertTrue(line.number is None)
 
@@ -46,102 +46,102 @@ class TestParser(unittest.TestCase):
         """The parser extracts a test number."""
         parser = Parser()
 
-        line = parser.parse_line('ok 42 is the magic number.')
+        line = parser.parse_line("ok 42 is the magic number.")
 
-        self.assertEqual('test', line.category)
+        self.assertEqual("test", line.category)
         self.assertEqual(42, line.number)
 
     def test_finds_description(self):
         parser = Parser()
 
-        line = parser.parse_line('ok 42 A passing test.')
+        line = parser.parse_line("ok 42 A passing test.")
 
-        self.assertEqual('test', line.category)
-        self.assertEqual('A passing test.', line.description)
+        self.assertEqual("test", line.category)
+        self.assertEqual("A passing test.", line.description)
 
     def test_after_hash_is_not_description(self):
         parser = Parser()
 
-        line = parser.parse_line('ok A description # Not part of description.')
+        line = parser.parse_line("ok A description # Not part of description.")
 
-        self.assertEqual('test', line.category)
-        self.assertEqual('A description', line.description)
+        self.assertEqual("test", line.category)
+        self.assertEqual("A description", line.description)
 
     def test_finds_todo(self):
         parser = Parser()
 
-        line = parser.parse_line('ok A description # TODO Not done')
+        line = parser.parse_line("ok A description # TODO Not done")
 
-        self.assertEqual('test', line.category)
+        self.assertEqual("test", line.category)
         self.assertTrue(line.todo)
 
     def test_finds_skip(self):
         parser = Parser()
 
-        line = parser.parse_line('ok A description # SKIP for now')
+        line = parser.parse_line("ok A description # SKIP for now")
 
-        self.assertEqual('test', line.category)
+        self.assertEqual("test", line.category)
         self.assertTrue(line.skip)
 
     def test_finds_not_ok(self):
         """The parser extracts a not ok line."""
         parser = Parser()
 
-        line = parser.parse_line('not ok - This is a failing test line.')
+        line = parser.parse_line("not ok - This is a failing test line.")
 
-        self.assertEqual('test', line.category)
+        self.assertEqual("test", line.category)
         self.assertFalse(line.ok)
         self.assertTrue(line.number is None)
-        self.assertEqual('', line.directive.text)
+        self.assertEqual("", line.directive.text)
 
     def test_finds_directive(self):
         """The parser extracts a directive"""
         parser = Parser()
-        test_line = 'not ok - This line fails # TODO not implemented'
+        test_line = "not ok - This line fails # TODO not implemented"
 
         line = parser.parse_line(test_line)
         directive = line.directive
 
-        self.assertEqual('test', line.category)
-        self.assertEqual('TODO not implemented', directive.text)
+        self.assertEqual("test", line.category)
+        self.assertEqual("TODO not implemented", directive.text)
         self.assertFalse(directive.skip)
         self.assertTrue(directive.todo)
-        self.assertEqual('not implemented', directive.reason)
+        self.assertEqual("not implemented", directive.reason)
 
     def test_unrecognizable_line(self):
         """The parser returns an unrecognizable line."""
         parser = Parser()
 
-        line = parser.parse_line('This is not a valid TAP line. # srsly')
+        line = parser.parse_line("This is not a valid TAP line. # srsly")
 
-        self.assertEqual('unknown', line.category)
+        self.assertEqual("unknown", line.category)
 
     def test_diagnostic_line(self):
         """The parser extracts a diagnostic line."""
-        text = '# An example diagnostic line'
+        text = "# An example diagnostic line"
         parser = Parser()
 
         line = parser.parse_line(text)
 
-        self.assertEqual('diagnostic', line.category)
+        self.assertEqual("diagnostic", line.category)
         self.assertEqual(text, line.text)
 
     def test_bail_out_line(self):
         """The parser extracts a bail out line."""
         parser = Parser()
 
-        line = parser.parse_line('Bail out! This is the reason to bail.')
+        line = parser.parse_line("Bail out! This is the reason to bail.")
 
-        self.assertEqual('bail', line.category)
-        self.assertEqual('This is the reason to bail.', line.reason)
+        self.assertEqual("bail", line.category)
+        self.assertEqual("This is the reason to bail.", line.reason)
 
     def test_finds_version(self):
         """The parser extracts a version line."""
         parser = Parser()
 
-        line = parser.parse_line('TAP version 13')
+        line = parser.parse_line("TAP version 13")
 
-        self.assertEqual('version', line.category)
+        self.assertEqual("version", line.category)
         self.assertEqual(13, line.version)
 
     def test_errors_on_old_version(self):
@@ -149,39 +149,40 @@ class TestParser(unittest.TestCase):
         parser = Parser()
 
         with self.assertRaises(ValueError):
-            parser.parse_line('TAP version 12')
+            parser.parse_line("TAP version 12")
 
     def test_finds_plan(self):
         """The parser extracts a plan line."""
         parser = Parser()
 
-        line = parser.parse_line('1..42')
+        line = parser.parse_line("1..42")
 
-        self.assertEqual('plan', line.category)
+        self.assertEqual("plan", line.category)
         self.assertEqual(42, line.expected_tests)
 
     def test_finds_plan_with_skip(self):
         """The parser extracts a plan line containing a SKIP."""
         parser = Parser()
 
-        line = parser.parse_line('1..42 # Skipping this test file.')
+        line = parser.parse_line("1..42 # Skipping this test file.")
 
-        self.assertEqual('plan', line.category)
+        self.assertEqual("plan", line.category)
         self.assertTrue(line.skip)
 
     def test_ignores_plan_with_any_non_skip_directive(self):
         """The parser only recognizes SKIP directives in plans."""
         parser = Parser()
 
-        line = parser.parse_line('1..42 # TODO will not work.')
+        line = parser.parse_line("1..42 # TODO will not work.")
 
-        self.assertEqual('unknown', line.category)
+        self.assertEqual("unknown", line.category)
 
     def test_parses_text(self):
         sample = inspect.cleandoc(
             u"""1..2
             ok 1 A passing test
-            not ok 2 A failing test""")
+            not ok 2 A failing test"""
+        )
         parser = Parser()
         lines = []
 
@@ -189,19 +190,20 @@ class TestParser(unittest.TestCase):
             lines.append(line)
 
         self.assertEqual(3, len(lines))
-        self.assertEqual('plan', lines[0].category)
-        self.assertEqual('test', lines[1].category)
+        self.assertEqual("plan", lines[0].category)
+        self.assertEqual("test", lines[1].category)
         self.assertTrue(lines[1].ok)
-        self.assertEqual('test', lines[2].category)
+        self.assertEqual("test", lines[2].category)
         self.assertFalse(lines[2].ok)
 
     def test_parses_file(self):
         sample = inspect.cleandoc(
             """1..2
             ok 1 A passing test
-            not ok 2 A failing test""")
+            not ok 2 A failing test"""
+        )
         temp = tempfile.NamedTemporaryFile(delete=False)
-        temp.write(sample.encode('utf-8'))
+        temp.write(sample.encode("utf-8"))
         temp.close()
         parser = Parser()
         lines = []
@@ -210,11 +212,11 @@ class TestParser(unittest.TestCase):
             lines.append(line)
 
         self.assertEqual(3, len(lines))
-        self.assertEqual('plan', lines[0].category)
-        self.assertEqual('test', lines[1].category)
+        self.assertEqual("plan", lines[0].category)
+        self.assertEqual("test", lines[1].category)
         self.assertTrue(lines[1].ok)
         self.assertIsNone(lines[1].yaml_block)
-        self.assertEqual('test', lines[2].category)
+        self.assertEqual("test", lines[2].category)
         self.assertFalse(lines[2].ok)
 
     def test_parses_yaml(self):
@@ -225,7 +227,8 @@ class TestParser(unittest.TestCase):
                ---
                test: sample yaml
                ...
-            not ok 2 A failing test""")
+            not ok 2 A failing test"""
+        )
         parser = Parser()
         lines = []
 
@@ -235,18 +238,19 @@ class TestParser(unittest.TestCase):
         try:
             import yaml
             from more_itertools import peekable  # noqa
+
             converted_yaml = yaml.load(u"""test: sample yaml""")
             self.assertEqual(4, len(lines))
             self.assertEqual(13, lines[0].version)
             self.assertEqual(converted_yaml, lines[2].yaml_block)
-            self.assertEqual('test', lines[3].category)
+            self.assertEqual("test", lines[3].category)
             self.assertIsNone(lines[3].yaml_block)
         except ImportError:
             self.assertEqual(7, len(lines))
             self.assertEqual(13, lines[0].version)
             for l in list(range(3, 6)):
-                self.assertEqual('unknown', lines[l].category)
-            self.assertEqual('test', lines[6].category)
+                self.assertEqual("unknown", lines[l].category)
+            self.assertEqual("test", lines[6].category)
 
     def test_parses_yaml_no_end(self):
         sample = inspect.cleandoc(
@@ -255,7 +259,8 @@ class TestParser(unittest.TestCase):
             ok 1 A passing test
                ---
                test: sample yaml
-            not ok 2 A failing test""")
+            not ok 2 A failing test"""
+        )
         parser = Parser()
         lines = []
 
@@ -265,18 +270,19 @@ class TestParser(unittest.TestCase):
         try:
             import yaml
             from more_itertools import peekable  # noqa
+
             converted_yaml = yaml.load(u"""test: sample yaml""")
             self.assertEqual(4, len(lines))
             self.assertEqual(13, lines[0].version)
             self.assertEqual(converted_yaml, lines[2].yaml_block)
-            self.assertEqual('test', lines[3].category)
+            self.assertEqual("test", lines[3].category)
             self.assertIsNone(lines[3].yaml_block)
         except ImportError:
             self.assertEqual(6, len(lines))
             self.assertEqual(13, lines[0].version)
             for l in list(range(3, 5)):
-                self.assertEqual('unknown', lines[l].category)
-            self.assertEqual('test', lines[5].category)
+                self.assertEqual("unknown", lines[l].category)
+            self.assertEqual("test", lines[5].category)
 
     def test_parses_yaml_more_complex(self):
         sample = inspect.cleandoc(
@@ -290,7 +296,8 @@ class TestParser(unittest.TestCase):
                  got:
                    - foo
                  expect:
-                   - bar""")
+                   - bar"""
+        )
         parser = Parser()
         lines = []
 
@@ -300,14 +307,17 @@ class TestParser(unittest.TestCase):
         try:
             import yaml
             from more_itertools import peekable  # noqa
-            converted_yaml = yaml.load(u"""
+
+            converted_yaml = yaml.load(
+                u"""
                message: test
                severity: fail
                data:
                  got:
                    - foo
                  expect:
-                   - bar""")
+                   - bar"""
+            )
             self.assertEqual(3, len(lines))
             self.assertEqual(13, lines[0].version)
             self.assertEqual(converted_yaml, lines[2].yaml_block)
@@ -315,7 +325,7 @@ class TestParser(unittest.TestCase):
             self.assertEqual(11, len(lines))
             self.assertEqual(13, lines[0].version)
             for l in list(range(3, 11)):
-                self.assertEqual('unknown', lines[l].category)
+                self.assertEqual("unknown", lines[l].category)
 
     def test_parses_yaml_no_association(self):
         sample = inspect.cleandoc(
@@ -326,7 +336,8 @@ class TestParser(unittest.TestCase):
                ---
                test: sample yaml
                ...
-            not ok 2 A failing test""")
+            not ok 2 A failing test"""
+        )
         parser = Parser()
         lines = []
 
@@ -336,10 +347,10 @@ class TestParser(unittest.TestCase):
         self.assertEqual(8, len(lines))
         self.assertEqual(13, lines[0].version)
         self.assertIsNone(lines[2].yaml_block)
-        self.assertEqual('diagnostic', lines[3].category)
+        self.assertEqual("diagnostic", lines[3].category)
         for l in list(range(4, 7)):
-            self.assertEqual('unknown', lines[l].category)
-        self.assertEqual('test', lines[7].category)
+            self.assertEqual("unknown", lines[l].category)
+        self.assertEqual("test", lines[7].category)
 
     def test_parses_yaml_no_start(self):
         sample = inspect.cleandoc(
@@ -348,7 +359,8 @@ class TestParser(unittest.TestCase):
             ok 1 A passing test
                test: sample yaml
                ...
-            not ok 2 A failing test""")
+            not ok 2 A failing test"""
+        )
         parser = Parser()
         lines = []
 
@@ -359,8 +371,8 @@ class TestParser(unittest.TestCase):
         self.assertEqual(13, lines[0].version)
         self.assertIsNone(lines[2].yaml_block)
         for l in list(range(3, 5)):
-            self.assertEqual('unknown', lines[l].category)
-        self.assertEqual('test', lines[5].category)
+            self.assertEqual("unknown", lines[l].category)
+        self.assertEqual("test", lines[5].category)
 
     def test_malformed_yaml(self):
         self.maxDiff = None
@@ -372,12 +384,14 @@ class TestParser(unittest.TestCase):
                test: sample yaml
                \tfail: tabs are not allowed!
                ...
-            not ok 2 A failing test""")
+            not ok 2 A failing test"""
+        )
         yaml_err = inspect.cleandoc(
             u"""
 WARNING: Optional imports not found, TAP 13 output will be
     ignored. To parse yaml, see requirements in docs:
-    https://tappy.readthedocs.io/en/latest/consumers.html#tap-version-13""")
+    https://tappy.readthedocs.io/en/latest/consumers.html#tap-version-13"""
+        )
         parser = Parser()
         lines = []
 
@@ -388,23 +402,23 @@ WARNING: Optional imports not found, TAP 13 output will be
         try:
             import yaml  # noqa
             from more_itertools import peekable  # noqa
+
             self.assertEqual(4, len(lines))
             self.assertEqual(13, lines[0].version)
             with captured_output() as (out, _):
                 self.assertIsNone(lines[2].yaml_block)
             self.assertEqual(
-                'Error parsing yaml block. Check formatting.',
-                out.getvalue().strip())
-            self.assertEqual('test', lines[3].category)
+                "Error parsing yaml block. Check formatting.", out.getvalue().strip()
+            )
+            self.assertEqual("test", lines[3].category)
             self.assertIsNone(lines[3].yaml_block)
         except ImportError:
             self.assertEqual(8, len(lines))
             self.assertEqual(13, lines[0].version)
             for l in list(range(3, 7)):
-                self.assertEqual('unknown', lines[l].category)
-            self.assertEqual('test', lines[7].category)
-            self.assertEqual(
-                yaml_err, parse_out.getvalue().strip())
+                self.assertEqual("unknown", lines[l].category)
+            self.assertEqual("test", lines[7].category)
+            self.assertEqual(yaml_err, parse_out.getvalue().strip())
 
     def test_parse_empty_file(self):
         temp = tempfile.NamedTemporaryFile(delete=False)
@@ -417,10 +431,14 @@ WARNING: Optional imports not found, TAP 13 output will be
 
         self.assertEqual(0, len(lines))
 
-    @mock.patch('tap.parser.sys.stdin',
-                StringIO(u"""1..2
+    @mock.patch(
+        "tap.parser.sys.stdin",
+        StringIO(
+            u"""1..2
 ok 1 A passing test
-not ok 2 A failing test"""))
+not ok 2 A failing test"""
+        ),
+    )
     def test_parses_stdin(self):
         parser = Parser()
         lines = []
@@ -429,8 +447,8 @@ not ok 2 A failing test"""))
             lines.append(line)
 
         self.assertEqual(3, len(lines))
-        self.assertEqual('plan', lines[0].category)
-        self.assertEqual('test', lines[1].category)
+        self.assertEqual("plan", lines[0].category)
+        self.assertEqual("test", lines[1].category)
         self.assertTrue(lines[1].ok)
-        self.assertEqual('test', lines[2].category)
+        self.assertEqual("test", lines[2].category)
         self.assertFalse(lines[2].ok)
